# User guide

Before you start reading further: 

- Check out available CLI commands in [[cli-commands|CLI Commands]] for signing.
- Check out [[config|Configuration]] for details on how to configure the signers.

Bellow you find details about supported signatures and signers. How they work and how you can validate
signatures produces by them.

* [[clear-sign|Clearsign]]
* [[container-signing|Containers Signing]]
* [[blob-signing|Blob Signing]]
